==> jc-1.4.0.tar.gz: java/security/UnresolvedPermission.h <==
// public final class java.security.UnresolvedPermission

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2377c76e79058a72 java_security_Permission
// @dep_class 538ad31d3f450a82 java_security_UnresolvedPermission

// header file dependencies
// @dep_header java_security_Permission

#include "java/security/Permission.h"

#ifndef _JC_java_security_UnresolvedPermission_H_
#define _JC_java_security_UnresolvedPermission_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_Permission$object;
struct _jc_java_security_PermissionCollection$object;

// Typedefs
typedef struct _jc_java_security_UnresolvedPermission$sub_refs	_jc_java_security_UnresolvedPermission$sub_refs;
typedef struct _jc_java_security_UnresolvedPermission$sub_nonrefs	_jc_java_security_UnresolvedPermission$sub_nonrefs;
typedef struct _jc_java_security_UnresolvedPermission$refs	_jc_java_security_UnresolvedPermission$refs;
typedef struct _jc_java_security_UnresolvedPermission$nonrefs	_jc_java_security_UnresolvedPermission$nonrefs;
typedef struct _jc_java_security_UnresolvedPermission$object	_jc_java_security_UnresolvedPermission$object;

typedef struct _jc_java_security_UnresolvedPermission$fields_struct	_jc_java_security_UnresolvedPermission$fields_struct;
typedef const struct _jc_java_security_UnresolvedPermission$vmethods	_jc_java_security_UnresolvedPermission$vmethods;
typedef const struct _jc_java_security_UnresolvedPermission$vtable	_jc_java_security_UnresolvedPermission$vtable;
typedef const struct _jc_java_security_UnresolvedPermission$vtype	_jc_java_security_UnresolvedPermission$vtype;

// Class fields structure
struct _jc_java_security_UnresolvedPermission$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_UnresolvedPermission$fields_struct _jc_java_security_UnresolvedPermission$class_fields;

// Constructors
extern void _jc_java_security_UnresolvedPermission$method$_init$cbc47e0df681ffd3(_jc_env *, struct _jc_java_security_UnresolvedPermission$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_object_array *);

// Virtual methods
extern jboolean _jc_java_security_UnresolvedPermission$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_security_UnresolvedPermission$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_String$object *_jc_java_security_UnresolvedPermission$method$getActions$a96d1cd349ac27ec(_jc_env *, struct _jc_java_security_UnresolvedPermission$object *);
extern jint _jc_java_security_UnresolvedPermission$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_security_UnresolvedPermission$object *);
extern jboolean _jc_java_security_UnresolvedPermission$method$implies$cbacf9d54b2bb917(_jc_env *, struct _jc_java_security_UnresolvedPermission$object *, struct _jc_java_security_Permission$object *);
extern struct _jc_java_security_PermissionCollection$object *_jc_java_security_UnresolvedPermission$method$newPermissionCollection$89e97753129a52a5(_jc_env *, struct _jc_java_security_UnresolvedPermission$object *);
extern struct _jc_java_lang_String$object *_jc_java_security_UnresolvedPermission$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_security_UnresolvedPermission$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_UnresolvedPermission$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_security_UnresolvedPermission$method_info$getActions$a96d1cd349ac27ec;
extern _jc_method _jc_java_security_UnresolvedPermission$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_security_UnresolvedPermission$method_info$implies$cbacf9d54b2bb917;
extern _jc_method _jc_java_security_UnresolvedPermission$method_info$newPermissionCollection$89e97753129a52a5;
extern _jc_method _jc_java_security_UnresolvedPermission$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_security_UnresolvedPermission$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_security_UnresolvedPermission$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_String$object	*(*getActions$a96d1cd349ac27ec)(_jc_env *, struct _jc_java_security_UnresolvedPermission$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_security_UnresolvedPermission$object *);
	jboolean	(*implies$cbacf9d54b2bb917)(_jc_env *, struct _jc_java_security_UnresolvedPermission$object *, struct _jc_java_security_Permission$object *);
	struct _jc_java_security_PermissionCollection$object	*(*newPermissionCollection$89e97753129a52a5)(_jc_env *, struct _jc_java_security_UnresolvedPermission$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_security_UnresolvedPermission$object *);
};

// Vtable
struct _jc_java_security_UnresolvedPermission$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_Permission$vmethods	java_security_Permission;
	_jc_java_security_UnresolvedPermission$vmethods	java_security_UnresolvedPermission;
};

// Vtype
struct _jc_java_security_UnresolvedPermission$vtype {
	_jc_type			type;
	_jc_java_security_UnresolvedPermission$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_UnresolvedPermission$sub_refs {
	struct _jc_java_lang_String$object	*actions;
	_jc_object_array	*certs;
	struct _jc_java_lang_String$object	*type;
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_java_security_UnresolvedPermission$refs {
    _jc_java_security_UnresolvedPermission$sub_refs	java_security_UnresolvedPermission;
    _jc_java_security_Permission$sub_refs	java_security_Permission;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_UnresolvedPermission$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_UnresolvedPermission$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_Permission$sub_nonrefs	java_security_Permission;
    _jc_java_security_UnresolvedPermission$sub_nonrefs	java_security_UnresolvedPermission;
};

// Object instance structure
struct _jc_java_security_UnresolvedPermission$object {
	_jc_java_security_UnresolvedPermission$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_UnresolvedPermission$vtype	*vtype;
	_jc_java_security_UnresolvedPermission$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_UnresolvedPermission$vtype _jc_java_security_UnresolvedPermission$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_UnresolvedPermission, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_UnresolvedPermission$class_object;

#endif	/* _JC_java_security_UnresolvedPermission_H_ */

==> jc-1.4.6.tar.gz: java/security/UnresolvedPermission.h <==
// public final class java.security.UnresolvedPermission

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2377c76e79058a72 java_security_Permission
// @dep_class 538ad31d3f450a82 java_security_UnresolvedPermission

// header file dependencies
// @dep_header java_security_Permission

#include "java/security/Permission.h"

#ifndef _JC_java_security_UnresolvedPermission_H_
#define _JC_java_security_UnresolvedPermission_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_Permission$object;
struct _jc_java_security_PermissionCollection$object;

// Typedefs
typedef struct _jc_java_security_UnresolvedPermission$sub_refs	_jc_java_security_UnresolvedPermission$sub_refs;
typedef struct _jc_java_security_UnresolvedPermission$sub_nonrefs	_jc_java_security_UnresolvedPermission$sub_nonrefs;
typedef struct _jc_java_security_UnresolvedPermission$refs	_jc_java_security_UnresolvedPermission$refs;
typedef struct _jc_java_security_UnresolvedPermission$nonrefs	_jc_java_security_UnresolvedPermission$nonrefs;
typedef struct _jc_java_security_UnresolvedPermission$object	_jc_java_security_UnresolvedPermission$object;

typedef struct _jc_java_security_UnresolvedPermission$fields_struct	_jc_java_security_UnresolvedPermission$fields_struct;
typedef const struct _jc_java_security_UnresolvedPermission$vmethods	_jc_java_security_UnresolvedPermission$vmethods;
typedef const struct _jc_java_security_UnresolvedPermission$vtable	_jc_java_security_UnresolvedPermission$vtable;
typedef const struct _jc_java_security_UnresolvedPermission$vtype	_jc_java_security_UnresolvedPermission$vtype;

// Class fields structure
struct _jc_java_security_UnresolvedPermission$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_UnresolvedPermission$fields_struct _jc_java_security_UnresolvedPermission$class_fields;

// Constructors
extern void _jc_java_security_UnresolvedPermission$method$_init$cbc47e0df681ffd3(_jc_env *, struct _jc_java_security_UnresolvedPermission$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_security_UnresolvedPermission$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_security_UnresolvedPermission$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_security_UnresolvedPermission$method$getActions$a96d1cd349ac27ec(_jc_env *, struct _jc_java_security_UnresolvedPermission$object *) _JC_JCNI_ATTR;
extern jint _jc_java_security_UnresolvedPermission$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_security_UnresolvedPermission$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_security_UnresolvedPermission$method$implies$cbacf9d54b2bb917(_jc_env *, struct _jc_java_security_UnresolvedPermission$object *, struct _jc_java_security_Permission$object *) _JC_JCNI_ATTR;
extern struct _jc_java_security_PermissionCollection$object *_jc_java_security_UnresolvedPermission$method$newPermissionCollection$89e97753129a52a5(_jc_env *, struct _jc_java_security_UnresolvedPermission$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_security_UnresolvedPermission$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_security_UnresolvedPermission$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_UnresolvedPermission$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_security_UnresolvedPermission$method_info$getActions$a96d1cd349ac27ec;
extern _jc_method _jc_java_security_UnresolvedPermission$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_security_UnresolvedPermission$method_info$implies$cbacf9d54b2bb917;
extern _jc_method _jc_java_security_UnresolvedPermission$method_info$newPermissionCollection$89e97753129a52a5;
extern _jc_method _jc_java_security_UnresolvedPermission$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_security_UnresolvedPermission$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_security_UnresolvedPermission$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getActions$a96d1cd349ac27ec)(_jc_env *, struct _jc_java_security_UnresolvedPermission$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_security_UnresolvedPermission$object *) _JC_JCNI_ATTR;
	jboolean	(*implies$cbacf9d54b2bb917)(_jc_env *, struct _jc_java_security_UnresolvedPermission$object *, struct _jc_java_security_Permission$object *) _JC_JCNI_ATTR;
	struct _jc_java_security_PermissionCollection$object	*(*newPermissionCollection$89e97753129a52a5)(_jc_env *, struct _jc_java_security_UnresolvedPermission$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_security_UnresolvedPermission$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_UnresolvedPermission$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_Permission$vmethods	java_security_Permission;
	_jc_java_security_UnresolvedPermission$vmethods	java_security_UnresolvedPermission;
};

// Vtype
struct _jc_java_security_UnresolvedPermission$vtype {
	_jc_type			type;
	_jc_java_security_UnresolvedPermission$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_UnresolvedPermission$sub_refs {
	struct _jc_java_lang_String$object	*actions;
	_jc_object_array	*certs;
	struct _jc_java_lang_String$object	*type;
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_java_security_UnresolvedPermission$refs {
    _jc_java_security_UnresolvedPermission$sub_refs	java_security_UnresolvedPermission;
    _jc_java_security_Permission$sub_refs	java_security_Permission;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_UnresolvedPermission$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_UnresolvedPermission$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_Permission$sub_nonrefs	java_security_Permission;
    _jc_java_security_UnresolvedPermission$sub_nonrefs	java_security_UnresolvedPermission;
};

// Object instance structure
struct _jc_java_security_UnresolvedPermission$object {
	_jc_java_security_UnresolvedPermission$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_UnresolvedPermission$vtype	*vtype;
	_jc_java_security_UnresolvedPermission$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_UnresolvedPermission$vtype _jc_java_security_UnresolvedPermission$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_UnresolvedPermission, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_UnresolvedPermission$class_object;

#endif	/* _JC_java_security_UnresolvedPermission_H_ */
